@@ -37,13 +37,13 @@ def encode(data):
     return new_data
 def data_desensitization(info):
     pat_rules=['\d{17}',#身份证
-               '\d{11}',#手机号
+               r'1(?:3\d|4[4-9]|5[0-35-9]|6[67]|7[013-8]|8\d|9\d)\d{8}',#手机号
                '\d{3}-\d{7}',#电话号
                '\w{1}@.*?\..{3}',#邮箱
                '\d{16}',#银行卡号1
                '\d{19}',#银行卡号2
-               '\d{4}-\d{2}-\d{2}',#出生年月1
-               '\d{8}',#出生年月2
+               #'\d{4}-\d{2}-\d{2}',#出生年月1
+               #'\d{8}',#出生年月2
                ]
     for pat in pat_rules:
         pat_rst=ppat(pat,info,0)
